Component

Struct Component 

pub struct Component { /* private fields */ }
A Component a discoverable entity in the distributed runtime. You can host Endpoint on a Component by first creating a Service then adding one or more Endpoint to the Service.

You can also issue a request to a Component’s Endpoint by creating a Client.

Implementations

Source

impl Component

pub fn instance_root(&self) -> String

The component part of an instance path in key-value store.

pub fn service_name(&self) -> String

pub fn path(&self) -> String

pub fn etcd_path(&self) -> EtcdPath

pub fn namespace(&self) -> &Namespace

pub fn name(&self) -> &str

pub fn labels(&self) -> &[(String, String)]

pub fn endpoint(&self, endpoint: impl Into<String>) -> Endpoint

pub async fn list_instances(&self) -> Result<Vec<Instance>>

pub async fn scrape_stats(&self, timeout: Duration) -> Result<ServiceSet>

Scrape ServiceSet, which contains NATS stats as well as user defined stats embedded in data field of ServiceInfo.

pub fn start_scraping_nats_service_component_metrics(&self) -> Result<()>

Add Prometheus metrics for this component’s NATS service stats.

Starts a background task that periodically requests service statistics from NATS and updates the corresponding Prometheus metrics. The first scrape happens immediately, then subsequent scrapes occur at a fixed interval of 9.8 seconds (MAX_WAIT_MS), which should be near or smaller than typical Prometheus scraping intervals to ensure metrics are fresh when Prometheus collects them.

pub async fn stats_stream(&self) -> Result<()>

TODO

This method will scrape the stats for all available services Returns a stream of ServiceInfo objects. This should be consumed by a [tokio::time::timeout_at] because each services will only respond once, but there is no way to know when all services have responded.

pub async fn add_stats_service(&mut self) -> Result<()>