pub struct Endpoint { /* private fields */ }Implementations
Sourceimpl Endpoint
impl Endpoint
Sourcepub async fn unregister_endpoint_instance(&self) -> Result<()>
pub async fn unregister_endpoint_instance(&self) -> Result<()>
Unregister this endpoint instance from discovery.
This removes the endpoint from the instances bucket, preventing the router from sending requests to this worker. Use this when a worker is sleeping and should not receive any requests.
Sourcepub async fn register_endpoint_instance(&self) -> Result<()>
pub async fn register_endpoint_instance(&self) -> Result<()>
Re-register this endpoint instance to discovery.
This adds the endpoint back to the instances bucket, allowing the router to send requests to this worker again. Use this when a worker wakes up and should start receiving requests.