pub async fn parallel_join<F1, F2, R1, R2>(
pool: &ComputePool,
f1: F1,
f2: F2,
) -> Result<(R1, R2)>Expand description
Execute two functions in parallel and return both results
pub async fn parallel_join<F1, F2, R1, R2>(
pool: &ComputePool,
f1: F1,
f2: F2,
) -> Result<(R1, R2)>Execute two functions in parallel and return both results