assert_compute_context

Function assert_compute_context 

pub fn assert_compute_context()
Assert that the current thread has compute context initialized

Panics if the thread-local context is not initialized. Use this to ensure compute macros will offload work rather than run inline.