pub fn try_acquire_block_permit() -> Result<OwnedSemaphorePermit, &'static str>Expand description
Try to acquire a block_in_place permit from thread-local context
Returns Ok(permit) if successful, Err if no context or no permits available
pub fn try_acquire_block_permit() -> Result<OwnedSemaphorePermit, &'static str>Try to acquire a block_in_place permit from thread-local context
Returns Ok(permit) if successful, Err if no context or no permits available