Modules
- environment_
names - Environment variable name constants for centralized management across the codebase
Structs
- Runtime
Config - Runtime configuration Defines the configuration for Tokio runtimes
- Runtime
Config Builder - Builder for
RuntimeConfig. - Worker
Config
Enums
- Console
LogFormat - Health
Status - Runtime
Config Builder Error - Error type for RuntimeConfigBuilder
Constants
- DEFAULT_
CANARY_ WAIT_ TIME_ SECS - Default health check configuration This is the wait time before sending canary health checks when no activity is detected
- DEFAULT_
HEALTH_ CHECK_ REQUEST_ TIMEOUT_ SECS - Default timeout for individual health check requests
Functions
- console_
log_ format - Return the console log format.
- disable_
ansi_ logging - Check whether logging with ANSI terminal escape codes and colors is disabled.
Set the
DYN_SDK_DISABLE_ANSI_LOGGINGenvironment variable ais_truthyvalue - env_
is_ falsey - Check if an environment variable is set to a falsey value (including set but empty). Unset (or non-unicode) variables are not falsey.
- env_
is_ truthy - Check if an environment variable is set to a truthy value. Unset (or non-unicode) variables are not truthy.
- is_
falsey - Check if a string is falsey:
0 | false | off | noor empty, case-insensitive, surrounding whitespace ignored. - is_
truthy - Check if a string is truthy:
1 | true | on | yes, case-insensitive, surrounding whitespace ignored. Everything else is not truthy. - jsonl_
logging_ enabled - Return whether the effective console log format is JSONL.
- parse_
bool - Parse a string as a boolean value, returning an error if it is neither truthy nor falsey.
- parse_
bool_ opt - Tri-state parse for call sites that preserve their own default unless the value is a deliberate boolean choice.
- span_
events_ enabled - Returns true if
DYN_LOGGING_SPAN_EVENTSis set to a truthy value. - use_
local_ timezone - Check whether to use local timezone for logging timestamps (default is UTC)
Set the
DYN_LOG_USE_LOCAL_TZenvironment variable to ais_truthyvalue