pub fn console_log_format() -> ConsoleLogFormatExpand description
Return the console log format.
DYN_LOGGING_CONSOLE_FORMAT takes precedence. DYN_LOGGING_JSONL remains
supported as a legacy fallback when the new setting is unset or blank.
pub fn console_log_format() -> ConsoleLogFormatReturn the console log format.
DYN_LOGGING_CONSOLE_FORMAT takes precedence. DYN_LOGGING_JSONL remains
supported as a legacy fallback when the new setting is unset or blank.