pub fn is_falsey(val: &str) -> boolExpand description
Check if a string is falsey This will be used to evaluate environment variables or any other subjective configuration parameters that can be set by the user that should be evaluated as a boolean value (opposite of is_truthy).