is_truthy

Function is_truthy 

pub fn is_truthy(val: &str) -> bool
Check if a string is truthy This will be used to evaluate environment variables or any other subjective configuration parameters that can be set by the user that should be evaluated as a boolean value.