pub enum DiscoveryInstanceId {
Endpoint(EndpointInstanceId),
Model(ModelCardInstanceId),
EventChannel(EventChannelInstanceId),
}Expand description
Union of instance identifiers for different discovery object types
Variants
Implementations
Sourceimpl DiscoveryInstanceId
impl DiscoveryInstanceId
Sourcepub fn instance_id(&self) -> u64
pub fn instance_id(&self) -> u64
Returns the raw instance_id regardless of variant type
Sourcepub fn extract_endpoint_id(&self) -> Result<&EndpointInstanceId>
pub fn extract_endpoint_id(&self) -> Result<&EndpointInstanceId>
Extracts the EndpointInstanceId, returning an error if this is a Model or EventChannel variant
Sourcepub fn extract_model_id(&self) -> Result<&ModelCardInstanceId>
pub fn extract_model_id(&self) -> Result<&ModelCardInstanceId>
Extracts the ModelCardInstanceId, returning an error if this is an Endpoint or EventChannel variant
Sourcepub fn extract_event_channel_id(&self) -> Result<&EventChannelInstanceId>
pub fn extract_event_channel_id(&self) -> Result<&EventChannelInstanceId>
Extracts the EventChannelInstanceId, returning an error if this is an Endpoint or Model variant