pub enum DiscoverySpec {
Endpoint {
namespace: String,
component: String,
endpoint: String,
transport: TransportType,
},
Model {
namespace: String,
component: String,
endpoint: String,
card_json: Value,
model_suffix: Option<String>,
},
EventChannel {
namespace: String,
component: String,
topic: String,
transport: EventTransport,
},
}Expand description
Specification for registering objects in the discovery plane Represents the input to the register() operation
Variants
Endpoint
Endpoint specification for registration
Fields
transport: TransportTypeTransport type and routing information
Model
Fields
EventChannel
Event plane channel specification Used for registering event publishers/subscribers for discovery
Implementations
Sourceimpl DiscoverySpec
impl DiscoverySpec
Sourcepub fn from_model<T>(
namespace: String,
component: String,
endpoint: String,
card: &T,
) -> Result<Self>where
T: Serialize,
pub fn from_model<T>(
namespace: String,
component: String,
endpoint: String,
card: &T,
) -> Result<Self>where
T: Serialize,
Creates a Model discovery spec from a serializable type The card will be serialized to JSON to avoid cross-crate dependencies
Sourcepub fn from_model_with_suffix<T>(
namespace: String,
component: String,
endpoint: String,
card: &T,
model_suffix: Option<String>,
) -> Result<Self>where
T: Serialize,
pub fn from_model_with_suffix<T>(
namespace: String,
component: String,
endpoint: String,
card: &T,
model_suffix: Option<String>,
) -> Result<Self>where
T: Serialize,
Creates a Model discovery spec with an optional suffix (e.g., for LoRA adapters) The suffix is appended after the instance_id in the key path
Sourcepub fn with_instance_id(self, instance_id: u64) -> DiscoveryInstance
pub fn with_instance_id(self, instance_id: u64) -> DiscoveryInstance
Attaches an instance ID to create a DiscoveryInstance