pub struct DiscoveryMetadata { /* private fields */ }Expand description
Metadata stored on each pod and exposed via HTTP endpoint This struct holds all discovery registrations for this pod instance
Implementations
Sourceimpl DiscoveryMetadata
impl DiscoveryMetadata
Sourcepub fn register_endpoint(&mut self, instance: DiscoveryInstance) -> Result<()>
pub fn register_endpoint(&mut self, instance: DiscoveryInstance) -> Result<()>
Register an endpoint instance
Sourcepub fn register_model_card(&mut self, instance: DiscoveryInstance) -> Result<()>
pub fn register_model_card(&mut self, instance: DiscoveryInstance) -> Result<()>
Register a model card instance
Sourcepub fn unregister_endpoint(
&mut self,
instance: &DiscoveryInstance,
) -> Result<()>
pub fn unregister_endpoint( &mut self, instance: &DiscoveryInstance, ) -> Result<()>
Unregister an endpoint instance
Sourcepub fn unregister_model_card(
&mut self,
instance: &DiscoveryInstance,
) -> Result<()>
pub fn unregister_model_card( &mut self, instance: &DiscoveryInstance, ) -> Result<()>
Unregister a model card instance
Sourcepub fn register_event_channel(
&mut self,
instance: DiscoveryInstance,
) -> Result<()>
pub fn register_event_channel( &mut self, instance: DiscoveryInstance, ) -> Result<()>
Register an event channel instance
Sourcepub fn unregister_event_channel(
&mut self,
instance: &DiscoveryInstance,
) -> Result<()>
pub fn unregister_event_channel( &mut self, instance: &DiscoveryInstance, ) -> Result<()>
Unregister an event channel instance
Sourcepub fn get_all_endpoints(&self) -> Vec<DiscoveryInstance>
pub fn get_all_endpoints(&self) -> Vec<DiscoveryInstance>
Get all registered endpoints
Sourcepub fn get_all_model_cards(&self) -> Vec<DiscoveryInstance>
pub fn get_all_model_cards(&self) -> Vec<DiscoveryInstance>
Get all registered model cards
Sourcepub fn get_all_event_channels(&self) -> Vec<DiscoveryInstance>
pub fn get_all_event_channels(&self) -> Vec<DiscoveryInstance>
Get all registered event channels
Sourcepub fn get_all(&self) -> Vec<DiscoveryInstance>
pub fn get_all(&self) -> Vec<DiscoveryInstance>
Get all registered instances (endpoints, model cards, and event channels)
Sourcepub fn filter(&self, query: &DiscoveryQuery) -> Vec<DiscoveryInstance>
pub fn filter(&self, query: &DiscoveryQuery) -> Vec<DiscoveryInstance>
Filter this metadata by query