DistributedRuntime

Struct DistributedRuntime 

pub struct DistributedRuntime { /* private fields */ }
Distributed Runtime which provides access to shared resources across the cluster, this includes communication protocols and transports.

Implementations

Source

impl DistributedRuntime

pub async fn new(runtime: Runtime, config: DistributedConfig) -> Result<Self>

pub async fn from_settings(runtime: Runtime) -> Result<Self>

pub fn runtime(&self) -> &Runtime

pub fn primary_token(&self) -> CancellationToken

pub fn component_registry(&self) -> &Registry

pub fn system_health(&self) -> Arc<Mutex<SystemHealth>>

pub fn local_endpoint_registry(&self) -> &LocalEndpointRegistry

Get the local endpoint registry for in-process endpoint calls

pub fn engine_routes(&self) -> &EngineRouteRegistry

Get the engine route registry for registering custom /engine/* routes

pub fn connection_id(&self) -> u64

pub fn shutdown(&self)

pub fn namespace(&self, name: impl Into<String>) -> Result<Namespace>

Create a Namespace

pub fn discovery(&self) -> Arc<dyn Discovery>

Returns the discovery interface for service registration and discovery

pub async fn tcp_server(&self) -> Result<Arc<TcpStreamServer>>

pub fn network_manager(&self) -> Arc<NetworkManager>

Get the network manager

The network manager consolidates all network configuration and provides unified access to request plane servers and clients.

pub async fn request_plane_server(&self) -> Result<Arc<dyn RequestPlaneServer>>

Get the request plane server (convenience method)

This is a shortcut for network_manager().await?.server().await.

pub fn system_status_server_info(&self) -> Option<Arc<SystemStatusServerInfo>>

Get system status server information if available

pub fn store(&self) -> &Manager

An interface to store things outside of the process. Usually backed by something like etcd. Currently does key-value, but will grow to include whatever we need to store.

pub fn request_plane(&self) -> RequestPlaneMode

How the frontend should talk to the backend.

pub fn child_token(&self) -> CancellationToken

pub fn instance_sources( &self, ) -> Arc<Mutex<HashMap<Endpoint, Weak<Receiver<Vec<Instance>>>>>>

pub async fn kv_router_nats_publish( &self, subject: String, payload: Bytes, ) -> Result<()>

TODO: This is a temporary KV router measure for component/component.rs EventPublisher impl for Component, to allow it to publish to NATS. KV Router is the only user.

When NATS is not available (e.g., running in approximate mode with –no-kv-events), this function returns Ok(()) silently since publishing is optional in that mode.

pub async fn kv_router_nats_request( &self, subject: String, payload: Bytes, timeout: Duration, ) -> Result<Message>

TODO (karenc): This is a temporary KV router measure for worker query requests. Allows KV Router to perform request/reply with workers. (versus the pub/sub pattern above) KV Router is the only user, made public for use in dynamo-llm crate

pub fn register_nats_service( &self, component: Component, ) -> Receiver<Result<(), String>>

DEPRECATED: This method exists only for NATS request plane support. Once everything uses the TCP request plane, this can be removed along with the NATS service registration infrastructure.

Returns a receiver that signals when the NATS service registration is complete. The caller should use blocking_recv() to wait for completion.