pub fn init()Expand description
Initialize logging (idempotent). Safe to call with or without a running Tokio runtime — OTLP exporters fall back to a persistent background runtime.
pub fn init()Initialize logging (idempotent). Safe to call with or without a running Tokio runtime — OTLP exporters fall back to a persistent background runtime.