compute_small

Macro compute_small 

macro_rules! compute_small {
    ($expr:expr) => { ... };
}
Execute a small compute task (<100μs) directly inline.

This macro has zero overhead and simply executes the expression directly. When validation is enabled, it will warn if the task takes >100μs.

Example

let result = compute_small!(2 + 2);
assert_eq!(result, 4);