pub fn init()Expand description
Initialise the NVTX subsystem from the DYN_ENABLE_RUST_NVTX environment variable.
Must be called once at runtime startup before any annotation macros fire.
No-op when the nvtx Cargo feature is off.
pub fn init()Initialise the NVTX subsystem from the DYN_ENABLE_RUST_NVTX environment variable.
Must be called once at runtime startup before any annotation macros fire.
No-op when the nvtx Cargo feature is off.