PipelineErrorExt

Trait PipelineErrorExt 

pub trait PipelineErrorExt {
    // Required methods
    fn try_into_pipeline_error(self) -> Result<PipelineError, Error>;
    fn either_pipeline_error(self) -> Either<PipelineError, Error>;
}

Required Methods

fn try_into_pipeline_error(self) -> Result<PipelineError, Error>

Downcast the Error to a PipelineError

fn either_pipeline_error(self) -> Either<PipelineError, Error>

If the Error can be downcast to a PipelineError, then the left variant is returned, otherwise the right variant is returned.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors