Codec Module
Codec map structure into blobs of bytes and streams of bytes.
In this module, we define three primary codec used to issue single, two-part or multi-part messages, on a byte stream.
Structs
- TcpRequest
Codec - Codec for encoding/decoding TcpRequestMessage Supports max_message_size enforcement
- TcpRequest
Message - TCP request plane protocol message with endpoint routing
- TcpResponse
Codec - Codec for encoding/decoding TcpResponseMessage Supports max_message_size enforcement
- TcpResponse
Message - TCP response message (acknowledgment or error)
- TwoPart
Codec - TwoPart
Message