pub type ManyOut<T> = EngineStream<T>;Expand description
Type alias for the output of pipeline that returns multiple values
Aliased Type
#[repr(transparent)]pub struct ManyOut<T> { /* private fields */ }pub type ManyOut<T> = EngineStream<T>;Type alias for the output of pipeline that returns multiple values
#[repr(transparent)]pub struct ManyOut<T> { /* private fields */ }