Modules
- annotated
- maybe_
error - MaybeError trait for types that may contain error information.
Structs
- Component
- Endpoint
Id - Represents an endpoint with a namespace, component, and name.
Constants
- ENDPOINT_
SCHEME - How we identify a namespace/component/endpoint URL. Technically the ‘://’ is not part of the scheme but it eliminates several string concatenations.