Slug

Struct Slug 

pub struct Slug(/* private fields */);
URL and NATS friendly string. Only a-z, 0-9, - and _.

Implementations

Source

impl Slug

pub fn from_string(s: impl AsRef<str>) -> Slug

Create Slug from a string.

pub fn slugify(s: &str) -> Slug

Turn the string into a valid slug, replacing any not-web-or-nats-safe characters with ‘-’

pub fn slugify_unique(s: &str) -> Slug

Like slugify but also add a four byte hash on the end, in case two different strings slug to the same thing (e.g. because of case differences).