pub struct Peekable<St>where
St: Stream,{ /* private fields */ }Expand description
A Stream that implements a peek method.
The peek method can be used to retrieve a reference
to the next Stream::Item if available. A subsequent
call to poll will return the owned item.
Implementations
Sourceimpl<St> Peekable<St>where
St: Stream,
impl<St> Peekable<St>where
St: Stream,
Sourcepub fn get_ref(&self) -> &St
pub fn get_ref(&self) -> &St
Acquires a reference to the underlying sink or stream that this combinator is pulling from.
Sourcepub fn get_mut(&mut self) -> &mut St
pub fn get_mut(&mut self) -> &mut St
Acquires a mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
Sourcepub fn get_pin_mut(self: Pin<&mut Peekable<St>>) -> Pin<&mut St>
pub fn get_pin_mut(self: Pin<&mut Peekable<St>>) -> Pin<&mut St>
Acquires a pinned mutable reference to the underlying sink or stream that this combinator is pulling from.
Note that care must be taken to avoid tampering with the state of the sink or stream which may otherwise confuse this combinator.
Sourcepub fn into_inner(self) -> St
pub fn into_inner(self) -> St
Consumes this combinator, returning the underlying sink or stream.
Note that this may discard intermediate state of this combinator, so care should be taken to avoid losing resources when this is called.
Sourcepub fn peek(self: Pin<&mut Peekable<St>>) -> Peek<'_, St> ⓘ
pub fn peek(self: Pin<&mut Peekable<St>>) -> Peek<'_, St> ⓘ
Produces a future which retrieves a reference to the next item
in the stream, or None if the underlying stream terminates.
Sourcepub fn poll_peek(
self: Pin<&mut Peekable<St>>,
cx: &mut Context<'_>,
) -> Poll<Option<&<St as Stream>::Item>>
pub fn poll_peek( self: Pin<&mut Peekable<St>>, cx: &mut Context<'_>, ) -> Poll<Option<&<St as Stream>::Item>>
Peek retrieves a reference to the next item in the stream.
This method polls the underlying stream and return either a reference to the next item if the stream is ready or passes through any errors.
Sourcepub fn peek_mut(self: Pin<&mut Peekable<St>>) -> PeekMut<'_, St> ⓘ
pub fn peek_mut(self: Pin<&mut Peekable<St>>) -> PeekMut<'_, St> ⓘ
Produces a future which retrieves a mutable reference to the next item
in the stream, or None if the underlying stream terminates.
Examples
use futures::stream::{self, StreamExt};
use futures::pin_mut;
let stream = stream::iter(vec![1, 2, 3]).peekable();
pin_mut!(stream);
assert_eq!(stream.as_mut().peek_mut().await, Some(&mut 1));
assert_eq!(stream.as_mut().next().await, Some(1));
// Peek into the stream and modify the value which will be returned next
if let Some(p) = stream.as_mut().peek_mut().await {
if *p == 2 {
*p = 5;
}
}
assert_eq!(stream.collect::<Vec<_>>().await, vec![5, 3]);Sourcepub fn poll_peek_mut(
self: Pin<&mut Peekable<St>>,
cx: &mut Context<'_>,
) -> Poll<Option<&mut <St as Stream>::Item>>
pub fn poll_peek_mut( self: Pin<&mut Peekable<St>>, cx: &mut Context<'_>, ) -> Poll<Option<&mut <St as Stream>::Item>>
Peek retrieves a mutable reference to the next item in the stream.
Sourcepub fn next_if<F>(self: Pin<&mut Peekable<St>>, func: F) -> NextIf<'_, St, F> ⓘ
pub fn next_if<F>(self: Pin<&mut Peekable<St>>, func: F) -> NextIf<'_, St, F> ⓘ
Creates a future which will consume and return the next value of this stream if a condition is true.
If func returns true for the next value of this stream, consume and
return it. Otherwise, return None.
Examples
Consume a number if it’s equal to 0.
use futures::stream::{self, StreamExt};
use futures::pin_mut;
let stream = stream::iter(0..5).peekable();
pin_mut!(stream);
// The first item of the stream is 0; consume it.
assert_eq!(stream.as_mut().next_if(|&x| x == 0).await, Some(0));
// The next item returned is now 1, so `consume` will return `false`.
assert_eq!(stream.as_mut().next_if(|&x| x == 0).await, None);
// `next_if` saves the value of the next item if it was not equal to `expected`.
assert_eq!(stream.next().await, Some(1));Consume any number less than 10.
use futures::stream::{self, StreamExt};
use futures::pin_mut;
let stream = stream::iter(1..20).peekable();
pin_mut!(stream);
// Consume all numbers less than 10
while stream.as_mut().next_if(|&x| x < 10).await.is_some() {}
// The next value returned will be 10
assert_eq!(stream.next().await, Some(10));Sourcepub fn next_if_eq<'a, T>(
self: Pin<&'a mut Peekable<St>>,
expected: &'a T,
) -> NextIfEq<'a, St, T> ⓘ
pub fn next_if_eq<'a, T>( self: Pin<&'a mut Peekable<St>>, expected: &'a T, ) -> NextIfEq<'a, St, T> ⓘ
Creates a future which will consume and return the next item if it is
equal to expected.
Example
Consume a number if it’s equal to 0.
use futures::stream::{self, StreamExt};
use futures::pin_mut;
let stream = stream::iter(0..5).peekable();
pin_mut!(stream);
// The first item of the stream is 0; consume it.
assert_eq!(stream.as_mut().next_if_eq(&0).await, Some(0));
// The next item returned is now 1, so `consume` will return `false`.
assert_eq!(stream.as_mut().next_if_eq(&0).await, None);
// `next_if_eq` saves the value of the next item if it was not equal to `expected`.
assert_eq!(stream.next().await, Some(1));Trait Implementations
Sourceimpl<St> FusedStream for Peekable<St>where
St: Stream,
impl<St> FusedStream for Peekable<St>where
St: Stream,
Sourcefn is_terminated(&self) -> bool
fn is_terminated(&self) -> bool
true if the stream should no longer be polled.Sourceimpl<S, Item> Sink<Item> for Peekable<S>
Available on crate feature sink only.
impl<S, Item> Sink<Item> for Peekable<S>
sink only.Sourcetype Error = <S as Sink<Item>>::Error
type Error = <S as Sink<Item>>::Error
Sourcefn poll_ready(
self: Pin<&mut Peekable<S>>,
cx: &mut Context<'_>,
) -> Poll<Result<(), <Peekable<S> as Sink<Item>>::Error>>
fn poll_ready( self: Pin<&mut Peekable<S>>, cx: &mut Context<'_>, ) -> Poll<Result<(), <Peekable<S> as Sink<Item>>::Error>>
Sink to receive a value. Read moreSourcefn start_send(
self: Pin<&mut Peekable<S>>,
item: Item,
) -> Result<(), <Peekable<S> as Sink<Item>>::Error>
fn start_send( self: Pin<&mut Peekable<S>>, item: Item, ) -> Result<(), <Peekable<S> as Sink<Item>>::Error>
poll_ready which returned Poll::Ready(Ok(())). Read moreSourceimpl<S> Stream for Peekable<S>where
S: Stream,
impl<S> Stream for Peekable<S>where
S: Stream,
Sourcefn poll_next(
self: Pin<&mut Peekable<S>>,
cx: &mut Context<'_>,
) -> Poll<Option<<Peekable<S> as Stream>::Item>>
fn poll_next( self: Pin<&mut Peekable<S>>, cx: &mut Context<'_>, ) -> Poll<Option<<Peekable<S> as Stream>::Item>>
None if the stream is exhausted. Read moreimpl<'__pin, St> Unpin for Peekable<St>