pub struct SystemHealth { /* private fields */ }Expand description
Current Health Status If use_endpoint_health_status is set then initialize the endpoint_health hashmap to the starting health status
Implementations
Sourceimpl SystemHealth
impl SystemHealth
pub fn new( starting_health_status: HealthStatus, use_endpoint_health_status: Vec<String>, health_path: String, live_path: String, ) -> Self
pub fn set_health_status(&mut self, status: HealthStatus)
pub fn set_endpoint_health_status(&self, endpoint: &str, status: HealthStatus)
Sourcepub fn get_health_status(&self) -> (bool, HashMap<String, String>)
pub fn get_health_status(&self) -> (bool, HashMap<String, String>)
Returns the overall health status and endpoint health statuses System health is determined by ALL endpoints that have registered health checks
Sourcepub fn register_health_check_target(
&self,
endpoint_subject: &str,
instance: Instance,
payload: Value,
)
pub fn register_health_check_target( &self, endpoint_subject: &str, instance: Instance, payload: Value, )
Register a health check target for an endpoint
Sourcepub fn get_health_check_targets(&self) -> Vec<(String, HealthCheckTarget)>
pub fn get_health_check_targets(&self) -> Vec<(String, HealthCheckTarget)>
Get all health check targets
Sourcepub fn has_health_check_targets(&self) -> bool
pub fn has_health_check_targets(&self) -> bool
Check if any health check targets are registered
Sourcepub fn get_health_check_endpoints(&self) -> Vec<String>
pub fn get_health_check_endpoints(&self) -> Vec<String>
Get list of endpoints with health check targets
Sourcepub fn get_health_check_target(
&self,
endpoint: &str,
) -> Option<HealthCheckTarget>
pub fn get_health_check_target( &self, endpoint: &str, ) -> Option<HealthCheckTarget>
Get health check target for a specific endpoint
Sourcepub fn get_endpoint_health_status(&self, endpoint: &str) -> Option<HealthStatus>
pub fn get_endpoint_health_status(&self, endpoint: &str) -> Option<HealthStatus>
Get the endpoint health status (Ready/NotReady)
Sourcepub fn get_endpoint_health_check_notifier(
&self,
endpoint_subject: &str,
) -> Option<Arc<Notify>>
pub fn get_endpoint_health_check_notifier( &self, endpoint_subject: &str, ) -> Option<Arc<Notify>>
Get the endpoint-specific health check notifier
Sourcepub fn take_new_endpoint_receiver(&self) -> Option<UnboundedReceiver<String>>
pub fn take_new_endpoint_receiver(&self) -> Option<UnboundedReceiver<String>>
Take the receiver for new endpoint registrations (can only be called once) This is used by HealthCheckManager to receive notifications of new endpoints
Sourcepub fn initialize_uptime_gauge<T: MetricsHierarchy>(
&self,
registry: &T,
) -> Result<()>
pub fn initialize_uptime_gauge<T: MetricsHierarchy>( &self, registry: &T, ) -> Result<()>
Initialize the uptime gauge using the provided metrics registry
Sourcepub fn update_uptime_gauge(&self)
pub fn update_uptime_gauge(&self)
Update the uptime gauge with the current uptime value
Sourcepub fn health_path(&self) -> &str
pub fn health_path(&self) -> &str
Get the health check path