Module system_status_server

Module system_status_server 

Structs

LoadLoraRequest
Request body for POST /v1/loras
LoraResponse
Response body for LoRA operations
LoraSource
Source information for loading a LoRA
SystemStatusServerInfo
System status server information containing socket address and handle
SystemStatusState
System status server state containing the distributed runtime reference

Functions

spawn_system_status_server
Start system status server with metrics support