Module traits

Module traits 

Traits

DistributedRuntimeProvider
A trait for objects that provide access to the DistributedRuntime.
RuntimeProvider
A trait for objects that proivde access to the Runtime