Module transports

Module transports 

The Transports module hosts all the network communication stacks used for talking to services or moving data around the network.

These are the low-level building blocks for the distributed system.

Modules

etcd
event_plane
Generic Event Plane for transport-agnostic pub/sub communication.
nats
NATS transport
tcp
zmq
ZMQ Transport