pub struct Client { /* private fields */ }Expand description
ETCD Client
Implementations
Sourceimpl Client
impl Client
pub fn builder() -> ClientOptionsBuilder
Sourcepub async fn new(config: ClientOptions, runtime: Runtime) -> Result<Self>
pub async fn new(config: ClientOptions, runtime: Runtime) -> Result<Self>
Create a new discovery client
This will establish a connection to the etcd server, create a primary lease,
and spawn a task to keep the lease alive and tie the lifetime of the Runtime
to the lease.
If the lease expires, the Runtime will be shutdown.
If the Runtime is shutdown, the lease will be revoked.
Sourcepub async fn kv_create(
&self,
key: &str,
value: Vec<u8>,
lease_id: Option<u64>,
) -> Result<Option<u64>>
pub async fn kv_create( &self, key: &str, value: Vec<u8>, lease_id: Option<u64>, ) -> Result<Option<u64>>
Atomically create a key-value pair if it doesn’t already exist.
Returns:
Ok(None)if the key was successfully createdOk(Some(version))if the key already exists (returns the existing version)Err(...)only on actual errors (connection failure, timeout, etc.)
This idempotent behavior was introduced in PR #4212 (Nov 10, 2025) to align with the StoreOutcome pattern used in KeyValueStore implementations, where both Created and Exists are successful outcomes rather than errors. This design supports distributed systems where multiple processes might attempt to create the same key.
Sourcepub async fn kv_create_or_validate(
&self,
key: String,
value: Vec<u8>,
lease_id: Option<u64>,
) -> Result<()>
pub async fn kv_create_or_validate( &self, key: String, value: Vec<u8>, lease_id: Option<u64>, ) -> Result<()>
Atomically create a key if it does not exist, or validate the values are identical if the key exists.
pub async fn kv_put( &self, key: impl AsRef<str>, value: impl AsRef<[u8]>, lease_id: Option<u64>, ) -> Result<()>
pub async fn kv_put_with_options( &self, key: impl AsRef<str>, value: impl AsRef<[u8]>, options: Option<PutOptions>, ) -> Result<PutResponse>
pub async fn kv_get( &self, key: impl Into<Vec<u8>>, options: Option<GetOptions>, ) -> Result<Vec<KeyValue>>
pub async fn kv_delete( &self, key: impl Into<Vec<u8>>, options: Option<DeleteOptions>, ) -> Result<u64>
pub async fn kv_get_prefix( &self, prefix: impl AsRef<str>, ) -> Result<Vec<KeyValue>>
Sourcepub async fn lock(
&self,
key: impl Into<Vec<u8>>,
lease_id: Option<u64>,
) -> Result<LockResponse>
pub async fn lock( &self, key: impl Into<Vec<u8>>, lease_id: Option<u64>, ) -> Result<LockResponse>
Acquire a distributed lock using etcd’s native lock mechanism Returns a LockResponse that can be used to unlock later
Sourcepub async fn unlock(&self, lock_key: impl Into<Vec<u8>>) -> Result<()>
pub async fn unlock(&self, lock_key: impl Into<Vec<u8>>) -> Result<()>
Release a distributed lock using the key from the LockResponse
Sourcepub async fn kv_watch_prefix(
&self,
prefix: impl AsRef<str> + Display,
) -> Result<PrefixWatcher>
pub async fn kv_watch_prefix( &self, prefix: impl AsRef<str> + Display, ) -> Result<PrefixWatcher>
Like kv_get_and_watch_prefix but only for new changes, does not include existing values.
pub async fn kv_get_and_watch_prefix( &self, prefix: impl AsRef<str> + Display, ) -> Result<PrefixWatcher>