KeyValue

Struct KeyValue 

pub struct KeyValue(/* private fields */);
Key-value pair.

Implementations

Source

impl KeyValue

pub fn key(&self) -> &[u8]

The key in bytes. An empty key is not allowed.

pub fn key_str(&self) -> Result<&str, Error>

The key in string. An empty key is not allowed.

pub unsafe fn key_str_unchecked(&self) -> &str

The key in string. An empty key is not allowed.

Safety

This function is unsafe because it does not check that the bytes of the key are valid UTF-8. If this constraint is violated, undefined behavior results, as the rest of Rust assumes that &strs are valid UTF-8.

pub fn value(&self) -> &[u8]

The value held by the key, in bytes.

pub fn value_str(&self) -> Result<&str, Error>

The value held by the key, in string.

pub unsafe fn value_str_unchecked(&self) -> &str

The value held by the key, in bytes.

Safety

This function is unsafe because it does not check that the bytes of the value are valid UTF-8. If this constraint is violated, undefined behavior results, as the rest of Rust assumes that &strs are valid UTF-8.

pub fn into_key_value(self) -> (Vec<u8>, Vec<u8>)

Convert to key-value pair.

pub const fn create_revision(&self) -> i64

The revision of last creation on this key.

pub const fn mod_revision(&self) -> i64

The revision of last modification on this key.

pub const fn version(&self) -> i64

The version of the key. A deletion resets the version to zero and any modification of the key increases its version.

pub const fn lease(&self) -> i64

The ID of the lease that attached to key. When the attached lease expires, the key will be deleted. If lease is 0, then no lease is attached to the key.