pub struct LeaseClient { /* private fields */ }Expand description
Client for lease operations.
Implementations
Sourceimpl LeaseClient
impl LeaseClient
Sourcepub async fn grant(
&mut self,
ttl: i64,
options: Option<LeaseGrantOptions>,
) -> Result<LeaseGrantResponse, Error>
pub async fn grant( &mut self, ttl: i64, options: Option<LeaseGrantOptions>, ) -> Result<LeaseGrantResponse, Error>
Creates a lease which expires if the server does not receive a keepAlive within a given time to live period. All keys attached to the lease will be expired and deleted if the lease expires. Each expired key generates a delete event in the event history.
Sourcepub async fn revoke(&mut self, id: i64) -> Result<LeaseRevokeResponse, Error>
pub async fn revoke(&mut self, id: i64) -> Result<LeaseRevokeResponse, Error>
Revokes a lease. All keys attached to the lease will expire and be deleted.
Sourcepub async fn keep_alive(
&mut self,
id: i64,
) -> Result<(LeaseKeeper, LeaseKeepAliveStream), Error>
pub async fn keep_alive( &mut self, id: i64, ) -> Result<(LeaseKeeper, LeaseKeepAliveStream), Error>
Keeps the lease alive by streaming keep alive requests from the client to the server and streaming keep alive responses from the server to the client.
Sourcepub async fn time_to_live(
&mut self,
id: i64,
options: Option<LeaseTimeToLiveOptions>,
) -> Result<LeaseTimeToLiveResponse, Error>
pub async fn time_to_live( &mut self, id: i64, options: Option<LeaseTimeToLiveOptions>, ) -> Result<LeaseTimeToLiveResponse, Error>
Retrieves lease information.
Sourcepub async fn leases(&mut self) -> Result<LeaseLeasesResponse, Error>
pub async fn leases(&mut self) -> Result<LeaseLeasesResponse, Error>
Lists all existing leases.