pub struct Client { /* private fields */ }Implementations
Sourceimpl Client
impl Client
Sourcepub fn builder() -> ClientOptionsBuilder
pub fn builder() -> ClientOptionsBuilder
Create a NATS ClientOptionsBuilder.
Sourcepub fn client(&self) -> &Client
pub fn client(&self) -> &Client
Returns a reference to the underlying async_nats::client::Client instance
Sourcepub fn jetstream(&self) -> &Context
pub fn jetstream(&self) -> &Context
Returns a reference to the underlying async_nats::jetstream::Context instance
Sourcepub async fn list_streams(&self) -> Result<Vec<String>>
pub async fn list_streams(&self) -> Result<Vec<String>>
fetch the list of streams
Sourcepub async fn list_consumers(&self, stream_name: &str) -> Result<Vec<String>>
pub async fn list_consumers(&self, stream_name: &str) -> Result<Vec<String>>
fetch the list of consumers for a given stream
pub async fn stream_info(&self, stream_name: &str) -> Result<State>
pub async fn get_stream(&self, name: &str) -> Result<Stream>
Sourcepub async fn scrape_service(&self, service_name: &str) -> Result<Subscriber>
pub async fn scrape_service(&self, service_name: &str) -> Result<Subscriber>
Issues a broadcast request for all services with the provided service_name to report their
current stats. Each service will only respond once. The service may have customized the reply
so the caller should select which endpoint and what concrete data model should be used to
extract the details.
Note: Because each endpoint will only reply once, the caller must drop the subscription after some time or it will await forever.
Sourcepub async fn object_store_upload(
&self,
filepath: &Path,
nats_url: &Url,
) -> Result<()>
pub async fn object_store_upload( &self, filepath: &Path, nats_url: &Url, ) -> Result<()>
Upload file to NATS at this URL
Sourcepub async fn object_store_download(
&self,
nats_url: &Url,
filepath: &Path,
) -> Result<()>
pub async fn object_store_download( &self, nats_url: &Url, filepath: &Path, ) -> Result<()>
Download file from NATS at this URL
Sourcepub async fn object_store_delete_bucket(&self, bucket_name: &str) -> Result<()>
pub async fn object_store_delete_bucket(&self, bucket_name: &str) -> Result<()>
Delete a bucket and all it’s contents from the NATS object store
Sourcepub async fn object_store_upload_data<T>(
&self,
data: &T,
nats_url: &Url,
) -> Result<()>where
T: Serialize,
pub async fn object_store_upload_data<T>(
&self,
data: &T,
nats_url: &Url,
) -> Result<()>where
T: Serialize,
Upload a serializable struct to NATS object store using bincode
Sourcepub async fn object_store_download_data<T>(&self, nats_url: &Url) -> Result<T>where
T: DeserializeOwned,
pub async fn object_store_download_data<T>(&self, nats_url: &Url) -> Result<T>where
T: DeserializeOwned,
Download and deserialize a struct from NATS object store using bincode