pub struct ClientOptions { /* private fields */ }Expand description
NATS client options
This object uses the builder pattern with default values that are evaluates from the environment variables if they are not explicitly set by the builder.
Implementations
Sourceimpl ClientOptions
impl ClientOptions
Sourcepub fn builder() -> ClientOptionsBuilder
pub fn builder() -> ClientOptionsBuilder
Create a new ClientOptionsBuilder