pub struct Server { /* private fields */ }Implementations
Sourceimpl Server
impl Server
Sourcepub async fn new(
context: &Context,
address: &str,
cancel_token: CancellationToken,
) -> Result<(Self, ServerExecutionHandle)>
pub async fn new( context: &Context, address: &str, cancel_token: CancellationToken, ) -> Result<(Self, ServerExecutionHandle)>
Create a new Server which is a async_zmq::Router with the given async_zmq::Context and address to bind the ZMQ async_zmq::Router socket.
If the event loop processing the router fails with an error, the signal is propagated through the CancellationToken by issuing a CancellationToken::cancel.
The Server is how you interact with the running instance.
The ServerExecutionHandle is the handle for background task executing the Server.