pub struct ServerExecutionHandle { /* private fields */ }Expand description
The ServerExecutionHandle is the handle for background task executing the Server.
You can use this to check if the server is finished or cancelled.
You can also join on the task to wait for it to finish.
Implementations
Sourceimpl ServerExecutionHandle
impl ServerExecutionHandle
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Check if the task awaiting on the Servers background event loop has finished.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Check if the server’s event loop has been cancelled.
Sourcepub fn cancel(&self)
pub fn cancel(&self)
Cancel the server’s event loop.
This will signal the server to stop processing requests and exit.
This will not wait for the server to finish, it will exit immediately.
This will not propagate to the CancellationToken used to start the Server unless an error happens during the shutdown process.