Module utils

Module utils 

Re-exports

pub use graceful_shutdown::GracefulShutdownTracker;
pub use graceful_shutdown::GracefulTaskGuard;
pub use ip_resolver::local_ip_for_advertise;
pub use ip_resolver::tcp_rpc_host_from_env;

Modules

graceful_shutdown
ip_resolver
Local IP address resolution for advertising endpoints.
pool
stream
task
tasks
typed_prefix_watcher
Generic etcd watcher utilities for maintaining collated state from etcd prefixes.

Structs

Duration
A Duration type to represent a span of time, typically used for system timeouts.
Instant
A measurement of a monotonically nondecreasing clock. Opaque and useful only with Duration.