Module ip_resolver

Module ip_resolver 

IP resolution utilities for getting local IP addresses with fallback support

Functions

get_http_rpc_host
Get the local IP address for HTTP RPC host binding using the default resolver
get_http_rpc_host_from_env
Get the HTTP RPC host from environment variable or resolve local IP as fallback
get_http_rpc_host_with_resolver
Get the local IP address for HTTP RPC host binding, using IpResolver with fallback to 127.0.0.1
get_tcp_rpc_host_from_env
Get the TCP RPC host from environment variable or resolve local IP as fallback