pub struct LeaderBarrier<LeaderData, WorkerData> { /* private fields */ }Expand description
A barrier for a leader to wait for a specific number of workers to join.
Implementations
Sourceimpl<LeaderData: Serialize + DeserializeOwned, WorkerData: Serialize + DeserializeOwned> LeaderBarrier<LeaderData, WorkerData>
impl<LeaderData: Serialize + DeserializeOwned, WorkerData: Serialize + DeserializeOwned> LeaderBarrier<LeaderData, WorkerData>
pub fn new( barrier_id: String, num_workers: usize, timeout: Option<Duration>, ) -> Self
Sourcepub async fn sync(
self,
rt: &DistributedRuntime,
data: &LeaderData,
) -> Result<HashMap<String, WorkerData>, LeaderWorkerBarrierError>
pub async fn sync( self, rt: &DistributedRuntime, data: &LeaderData, ) -> Result<HashMap<String, WorkerData>, LeaderWorkerBarrierError>
Synchronize the leader with the workers.
The leader will publish the barrier data, and the workers will wait for the barrier data to appear. The leader will then signal completion or abort, and the workers will wait for the signal to appear.