Returnable

Trait Returnable 

pub trait Returnable:
    Send
    + Sync
    + 'static {
    // Provided method
    fn on_return(&mut self) { ... }
}
Trait for items that can be returned to a pool

Provided Methods

fn on_return(&mut self)

Called when an item is returned to the pool

Implementors