Crate dynamo_runtime

Crate dynamo_runtime 

Dynamo

Re-exports

pub use config::RuntimeConfig;
pub use system_status_server::SystemStatusServerInfo;
pub use distributed::DistributedRuntime;
pub use distributed::distributed_test_utils;
pub use metrics::MetricsRegistry;
pub use runtime::Runtime;
pub use system_health::HealthCheckTarget;
pub use system_health::SystemHealth;
pub use worker::Worker;

Modules

component
The Component module defines the top-level API for building distributed applications.
compute
Compute module for CPU-intensive operations using Rayon
config
discovery
distributed
engine
Asynchronous Engine System with Type Erasure Support
engine_routes
error
Dynamo Error System
health_check
instances
Instance management functions for the distributed runtime.
local_endpoint_registry
Local Endpoint Registry
logging
Dynamo Distributed Logging Module.
metrics
Metrics registry trait and implementation for Prometheus metrics
nvtx
NVTX timeline-annotation helpers for Nsight Systems profiling.
pipeline
prelude
protocols
runnable
Runnable Module.
runtime
The Runtime module is the interface for crate::component::Component to access shared resources. These include thread pool, memory allocators and other shared resources.
service
slug
storage
stream
Asynchronous streams.
system_health
System health monitoring and health check management
system_status_server
traits
transports
The Transports module hosts all the network communication stacks used for talking to services or moving data around the network.
utils
worker
The Worker class is a convenience wrapper around the construction of the Runtime and execution of the users application.

Macros

compute_large
Execute a large compute task (>1ms) on the Rayon thread pool.
compute_medium
Execute a medium compute task (100μs-1ms) with intelligent scheduling.
compute_small
Execute a small compute task (<100μs) directly inline.
dynamo_nvtx_name_thread
Annotate the current OS thread in the Nsight Systems timeline. Zero-cost when the nvtx Cargo feature is off.
dynamo_nvtx_pop
Pop the innermost NVTX range from the calling thread’s stack. Zero-cost when the nvtx Cargo feature is off.
dynamo_nvtx_push
Push a named NVTX range onto the calling thread’s stack. Zero-cost when the nvtx Cargo feature is off.
dynamo_nvtx_range
Open a named NVTX range that closes automatically at end of scope.
error
Construct an ad-hoc error from a string or existing non-anyhow error value.
raise
Return early with an error.

Structs

CancellationToken
A token which can be used to signal a cancellation request to one or more tasks.
Error
The Error type, a wrapper around a dynamic error type.

Traits

ErrorContext
Provides the context method for Result.

Functions

OK
Equivalent to Ok::<_, anyhow::Error>(value).

Type Aliases

Result
Result<T, Error>