pub fn assert_compute_context()Expand description
Assert that the current thread has compute context initialized
Panics if the thread-local context is not initialized. Use this to ensure compute macros will offload work rather than run inline.
pub fn assert_compute_context()Assert that the current thread has compute context initialized
Panics if the thread-local context is not initialized. Use this to ensure compute macros will offload work rather than run inline.