Module config

Module config 

Modules

environment_names
Environment variable name constants for centralized management across the codebase

Structs

RuntimeConfig
Runtime configuration Defines the configuration for Tokio runtimes
RuntimeConfigBuilder
Builder for RuntimeConfig.
WorkerConfig

Enums

HealthStatus
RuntimeConfigBuilderError
Error type for RuntimeConfigBuilder

Constants

DEFAULT_CANARY_WAIT_TIME_SECS
Default health check configuration This is the wait time before sending canary health checks when no activity is detected
DEFAULT_HEALTH_CHECK_REQUEST_TIMEOUT_SECS
Default timeout for individual health check requests

Functions

disable_ansi_logging
Check whether logging with ANSI terminal escape codes and colors is disabled. Set the DYN_SDK_DISABLE_ANSI_LOGGING environment variable a is_truthy value
env_is_falsey
Check if an environment variable is set to a falsey value (including set but empty). Unset (or non-unicode) variables are not falsey.
env_is_truthy
Check if an environment variable is set to a truthy value. Unset (or non-unicode) variables are not truthy.
is_falsey
Check if a string is falsey: 0 | false | off | no or empty, case-insensitive, surrounding whitespace ignored.
is_truthy
Check if a string is truthy: 1 | true | on | yes, case-insensitive, surrounding whitespace ignored. Everything else is not truthy.
jsonl_logging_enabled
Check whether JSONL logging enabled Set the DYN_LOGGING_JSONL environment variable a is_truthy value
parse_bool
Parse a string as a boolean value, returning an error if it is neither truthy nor falsey.
parse_bool_opt
Tri-state parse for call sites that preserve their own default unless the value is a deliberate boolean choice.
span_events_enabled
Returns true if DYN_LOGGING_SPAN_EVENTS is set to a truthy value.
use_local_timezone
Check whether to use local timezone for logging timestamps (default is UTC) Set the DYN_LOG_USE_LOCAL_TZ environment variable to a is_truthy value