Modules
- environment_
names - Environment variable name constants for centralized management across the codebase
Structs
- Runtime
Config - Runtime configuration Defines the configuration for Tokio runtimes
- Runtime
Config Builder - Builder for
RuntimeConfig. - Worker
Config
Enums
- Health
Status - Runtime
Config Builder Error - Error type for RuntimeConfigBuilder
Constants
- DEFAULT_
CANARY_ WAIT_ TIME_ SECS - Default health check configuration This is the wait time before sending canary health checks when no activity is detected
- DEFAULT_
HEALTH_ CHECK_ REQUEST_ TIMEOUT_ SECS - Default timeout for individual health check requests
Functions
- disable_
ansi_ logging - Check whether logging with ANSI terminal escape codes and colors is disabled.
Set the
DYN_SDK_DISABLE_ANSI_LOGGINGenvironment variable ais_truthyvalue - env_
is_ falsey - Check if an environment variable is falsey
- env_
is_ truthy - Check if an environment variable is truthy
- is_
falsey - Check if a string is falsey This will be used to evaluate environment variables or any other subjective configuration parameters that can be set by the user that should be evaluated as a boolean value (opposite of is_truthy).
- is_
truthy - Check if a string is truthy This will be used to evaluate environment variables or any other subjective configuration parameters that can be set by the user that should be evaluated as a boolean value.
- jsonl_
logging_ enabled - Check whether JSONL logging enabled
Set the
DYN_LOGGING_JSONLenvironment variable ais_truthyvalue - parse_
bool - span_
events_ enabled - Returns true if
DYN_LOGGING_SPAN_EVENTSis set to a truthy value. - use_
local_ timezone - Check whether to use local timezone for logging timestamps (default is UTC)
Set the
DYN_LOG_USE_LOCAL_TZenvironment variable to ais_truthyvalue