Module config

Module config 

Modules

environment_names
Environment variable name constants for centralized management across the codebase

Structs

RuntimeConfig
Runtime configuration Defines the configuration for Tokio runtimes
RuntimeConfigBuilder
Builder for RuntimeConfig.
WorkerConfig

Enums

HealthStatus
RuntimeConfigBuilderError
Error type for RuntimeConfigBuilder

Constants

DEFAULT_CANARY_WAIT_TIME_SECS
Default health check configuration This is the wait time before sending canary health checks when no activity is detected
DEFAULT_HEALTH_CHECK_REQUEST_TIMEOUT_SECS
Default timeout for individual health check requests

Functions

disable_ansi_logging
Check whether logging with ANSI terminal escape codes and colors is disabled. Set the DYN_SDK_DISABLE_ANSI_LOGGING environment variable a is_truthy value
env_is_falsey
Check if an environment variable is falsey
env_is_truthy
Check if an environment variable is truthy
is_falsey
Check if a string is falsey This will be used to evaluate environment variables or any other subjective configuration parameters that can be set by the user that should be evaluated as a boolean value (opposite of is_truthy).
is_truthy
Check if a string is truthy This will be used to evaluate environment variables or any other subjective configuration parameters that can be set by the user that should be evaluated as a boolean value.
jsonl_logging_enabled
Check whether JSONL logging enabled Set the DYN_LOGGING_JSONL environment variable a is_truthy value
parse_bool
use_local_timezone
Check whether to use local timezone for logging timestamps (default is UTC) Set the DYN_LOG_USE_LOCAL_TZ environment variable to a is_truthy value