Environment variable name constants for centralized management across the codebase
This module provides centralized environment variable name constants to ensure
consistency and avoid duplication across the codebase, similar to how
prometheus_names.rs manages metric names.
Organization
Environment variables are organized by functional area:
- Logging: Log level, configuration, and OTLP tracing
- Runtime: Tokio runtime configuration and system server settings
- NATS: NATS client connection and authentication
- ETCD: ETCD client connection and authentication
- TCP Response Stream: TCP response stream server (CallHome) port and host
- Event Plane: Event transport selection (NATS)
- KVBM: Key-Value Block Manager configuration
- LLM: Language model inference configuration
- Model: Model loading and caching
- Worker: Worker lifecycle and shutdown
- Testing: Test-specific configuration
- Mocker: Mocker (mock scheduler/KV manager) configuration
Modules
- build
- Build-time environment variables
- cuda
- CUDA and GPU environment variables
- discovery
- Discovery environment variables
- etcd
- ETCD transport environment variables
- event_
plane - Event Plane transport environment variables
- kvbm
- Key-Value Block Manager (KVBM) environment variables
- llm
- LLM (Language Model) inference environment variables
- logging
- Logging and tracing environment variables
- mocker
- Mocker (mock scheduler/KV manager) environment variables
- model
- Model loading and caching environment variables
- nats
- NATS transport environment variables
- request_
plane - Request plane transport environment variables
- router
- KV Router configuration environment variables
- runtime
- Runtime configuration environment variables
- tcp_
response_ stream - TCP response stream server (CallHome listener) environment variables
- testing
- Testing environment variables
- worker
- Worker lifecycle environment variables
- zmq_
broker - ZMQ Broker environment variables