pub struct RuntimeConfigBuilder { /* private fields */ }Expand description
Builder for RuntimeConfig.
Implementations
Sourceimpl RuntimeConfigBuilder
impl RuntimeConfigBuilder
Sourcepub fn num_worker_threads(&mut self, value: Option<usize>) -> &mut Self
pub fn num_worker_threads(&mut self, value: Option<usize>) -> &mut Self
Number of async worker threads If set to 1, the runtime will run in single-threaded mode Set this at runtime with environment variable DYN_RUNTIME_NUM_WORKER_THREADS. Defaults to number of cores.
Sourcepub fn max_blocking_threads(&mut self, value: usize) -> &mut Self
pub fn max_blocking_threads(&mut self, value: usize) -> &mut Self
Maximum number of blocking threads Blocking threads are used for blocking operations, this value must be greater than 0. Set this at runtime with environment variable DYN_RUNTIME_MAX_BLOCKING_THREADS. Defaults to 512.
Sourcepub fn system_host(&mut self, value: String) -> &mut Self
pub fn system_host(&mut self, value: String) -> &mut Self
System status server host for health and metrics endpoints Set this at runtime with environment variable DYN_SYSTEM_HOST
Sourcepub fn system_port(&mut self, value: i16) -> &mut Self
pub fn system_port(&mut self, value: i16) -> &mut Self
System status server port for health and metrics endpoints Set to -1 to disable the system status server (default) Set to 0 to bind to a random available port Set to a positive port number (e.g. 8081) to bind to a specific port Set this at runtime with environment variable DYN_SYSTEM_PORT
Sourcepub fn system_enabled(&mut self, value: bool) -> &mut Self
pub fn system_enabled(&mut self, value: bool) -> &mut Self
Health and metrics System status server enabled (DEPRECATED) This field is deprecated. Use system_port instead (set to positive value to enable) Environment variable DYN_SYSTEM_ENABLED is deprecated
Sourcepub fn starting_health_status(&mut self, value: HealthStatus) -> &mut Self
pub fn starting_health_status(&mut self, value: HealthStatus) -> &mut Self
Starting Health Status Set this at runtime with environment variable DYN_SYSTEM_STARTING_HEALTH_STATUS
Sourcepub fn use_endpoint_health_status(&mut self, value: Vec<String>) -> &mut Self
pub fn use_endpoint_health_status(&mut self, value: Vec<String>) -> &mut Self
Use Endpoint Health Status When using endpoint health status, health status is the AND of individual endpoint health Set this at runtime with environment variable DYN_SYSTEM_USE_ENDPOINT_HEALTH_STATUS with the list of endpoints to consider for system health
Sourcepub fn system_health_path(&mut self, value: String) -> &mut Self
pub fn system_health_path(&mut self, value: String) -> &mut Self
Health endpoint paths Set this at runtime with environment variable DYN_SYSTEM_HEALTH_PATH
Sourcepub fn system_live_path(&mut self, value: String) -> &mut Self
pub fn system_live_path(&mut self, value: String) -> &mut Self
Set this at runtime with environment variable DYN_SYSTEM_LIVE_PATH
Sourcepub fn compute_threads(&mut self, value: Option<usize>) -> &mut Self
pub fn compute_threads(&mut self, value: Option<usize>) -> &mut Self
Number of threads for the Rayon compute pool If not set, defaults to num_cpus / 2 Set this at runtime with environment variable DYN_COMPUTE_THREADS
Sourcepub fn compute_stack_size(&mut self, value: Option<usize>) -> &mut Self
pub fn compute_stack_size(&mut self, value: Option<usize>) -> &mut Self
Stack size for compute threads in bytes Defaults to 2MB (2097152 bytes) Set this at runtime with environment variable DYN_COMPUTE_STACK_SIZE
Sourcepub fn compute_thread_prefix(&mut self, value: String) -> &mut Self
pub fn compute_thread_prefix(&mut self, value: String) -> &mut Self
Thread name prefix for compute pool threads Set this at runtime with environment variable DYN_COMPUTE_THREAD_PREFIX
Sourcepub fn health_check_enabled(&mut self, value: bool) -> &mut Self
pub fn health_check_enabled(&mut self, value: bool) -> &mut Self
Enable active health checking with payloads Set this at runtime with environment variable DYN_HEALTH_CHECK_ENABLED
Sourcepub fn canary_wait_time_secs(&mut self, value: u64) -> &mut Self
pub fn canary_wait_time_secs(&mut self, value: u64) -> &mut Self
Canary wait time in seconds (time to wait before sending health check when no activity) Set this at runtime with environment variable DYN_CANARY_WAIT_TIME
Sourcepub fn health_check_request_timeout_secs(&mut self, value: u64) -> &mut Self
pub fn health_check_request_timeout_secs(&mut self, value: u64) -> &mut Self
Health check request timeout in seconds Set this at runtime with environment variable DYN_HEALTH_CHECK_REQUEST_TIMEOUT
Sourceimpl RuntimeConfigBuilder
impl RuntimeConfigBuilder
Sourcepub fn build(&self) -> Result<RuntimeConfig>
pub fn build(&self) -> Result<RuntimeConfig>
Build and validate the runtime configuration