Module discovery
Source pub use utils::watch_and_extract_field;
- utils
- Utility functions for working with discovery streams
- DiscoveryMetadata
- Metadata stored on each pod and exposed via HTTP endpoint
This struct holds all discovery registrations for this pod instance
- KVStoreDiscovery
- Discovery implementation backed by a KeyValueStore
- KubeDiscoveryClient
- Kubernetes-based discovery client
- MetadataSnapshot
- Snapshot of all discovered instances and their metadata
- MockDiscovery
- Mock implementation of Discovery for testing
We can potentially remove this once we have KVStoreDiscovery fully tested
- SharedMockRegistry
- Shared in-memory registry for mock discovery
- DiscoveryEvent
- Events emitted by the discovery watch stream
- DiscoveryInstance
- Registered instances in the discovery plane
Represents objects that have been successfully registered with an instance ID
- DiscoveryQuery
- Query key for prefix-based discovery queries
Supports hierarchical queries from all endpoints down to specific endpoints
- DiscoverySpec
- Specification for registering objects in the discovery plane
Represents the input to the register() operation
- Discovery
- Discovery trait for service discovery across different backends
- hash_pod_name
- Hash a pod name to get a consistent instance ID
- DiscoveryStream
- Stream type for discovery events