Module distributed

Module distributed 

Modules

distributed_test_utils
Common test helper functions for DistributedRuntime tests

Structs

DistributedConfig
DistributedRuntime
Distributed Runtime which provides access to shared resources across the cluster, this includes communication protocols and transports.

Enums

DiscoveryBackend
Selects which discovery backend to use and, for KV store backends, which KV store.
RequestPlaneMode
Request plane transport mode configuration