Modules
- distributed_
test_ utils - Common test helper functions for DistributedRuntime tests
Structs
- Distributed
Config - Distributed
Runtime - Distributed Runtime which provides access to shared resources across the cluster, this includes communication protocols and transports.
Enums
- Discovery
Backend - Selects which discovery backend to use and, for KV store backends, which KV store.
- Request
Plane Mode - Request plane transport mode configuration