pub struct DistributedRuntime { /* private fields */ }Expand description
Distributed Runtime which provides access to shared resources across the cluster, this includes communication protocols and transports.
Implementations
Sourceimpl DistributedRuntime
impl DistributedRuntime
pub async fn new(runtime: Runtime, config: DistributedConfig) -> Result<Self>
pub async fn from_settings(runtime: Runtime) -> Result<Self>
pub async fn from_settings_without_discovery(runtime: Runtime) -> Result<Self>
pub fn runtime(&self) -> &Runtime
pub fn primary_token(&self) -> CancellationToken
pub fn component_registry(&self) -> &Registry
pub fn system_health(&self) -> Arc<Mutex<SystemHealth>> ⓘ
pub fn connection_id(&self) -> u64
pub fn shutdown(&self)
Sourcepub fn discovery(&self) -> Arc<dyn Discovery>
pub fn discovery(&self) -> Arc<dyn Discovery>
Returns the discovery interface for service registration and discovery
pub async fn tcp_server(&self) -> Result<Arc<TcpStreamServer>>
Sourcepub async fn network_manager(&self) -> Result<Arc<NetworkManager>>
pub async fn network_manager(&self) -> Result<Arc<NetworkManager>>
Get the network manager (lazy initialization)
The network manager consolidates all network configuration and provides unified access to request plane servers and clients.
Sourcepub async fn request_plane_server(&self) -> Result<Arc<dyn RequestPlaneServer>>
pub async fn request_plane_server(&self) -> Result<Arc<dyn RequestPlaneServer>>
Get the request plane server (convenience method)
This is a shortcut for network_manager().await?.server().await.
Sourcepub async fn http_server(&self) -> Result<Arc<SharedHttpServer>>
👎Deprecated: Use request_plane_server() or network_manager().server() instead
pub async fn http_server(&self) -> Result<Arc<SharedHttpServer>>
DEPRECATED: Use network_manager().server() instead
👎Deprecated: Use request_plane_server() or network_manager().server() instead
DEPRECATED: Use network_manager().server() instead
pub fn nats_client(&self) -> Option<&Client>
Sourcepub fn system_status_server_info(&self) -> Option<Arc<SystemStatusServerInfo>>
pub fn system_status_server_info(&self) -> Option<Arc<SystemStatusServerInfo>>
Get system status server information if available
pub fn etcd_client(&self) -> Option<Client>
Sourcepub fn store(&self) -> &KeyValueStoreManager
pub fn store(&self) -> &KeyValueStoreManager
An interface to store things. Will eventually replace etcd_client.
Currently does key-value, but will grow to include whatever we need to store.
pub fn child_token(&self) -> CancellationToken
pub fn instance_sources( &self, ) -> Arc<Mutex<HashMap<Endpoint, Weak<InstanceSource>>>>