Metrics registry trait and implementation for Prometheus metrics
This module provides a trait-based interface for creating and managing Prometheus metrics with automatic label injection and hierarchical naming support.
Modules
- prometheus_
names - Prometheus metric name constants and sanitization utilities
Structs
- Metrics
- Wrapper struct that provides access to metrics functionality
This struct is accessed via the
.metrics()method on DistributedRuntime, Namespace, Component, and Endpoint - Metrics
Registry - Structure to hold Prometheus registries and associated callbacks for a given hierarchy.
Constants
Traits
- Metrics
Hierarchy - Prometheus
Metric - ============================== Prometheus section
Functions
- create_
metric - ============================== Metrics section
Type Aliases
- Prometheus
Exposition Format Callback - Type alias for exposition text callback functions that return Prometheus text
- Prometheus
Update Callback - Type alias for runtime callback functions to reduce complexity