ConnectOptions

Struct ConnectOptions 

pub struct ConnectOptions { /* private fields */ }
Options for Connect operation.

Implementations

Source

impl ConnectOptions

pub fn with_user( self, name: impl Into<String>, password: impl Into<String>, ) -> ConnectOptions

name is the identifier for the distributed shared lock to be acquired.

pub fn with_tls(self, tls: ClientTlsConfig) -> ConnectOptions

Sets TLS options.

Notes that this function have to work with HTTPS URLs.

pub fn with_keep_alive( self, interval: Duration, timeout: Duration, ) -> ConnectOptions

Enable HTTP2 keep-alive with interval and timeout.

pub fn with_timeout(self, timeout: Duration) -> ConnectOptions

Apply a timeout to each request.

pub fn with_connect_timeout(self, timeout: Duration) -> ConnectOptions

Apply a timeout to connecting to the endpoint.

pub fn with_tcp_keepalive(self, tcp_keepalive: Duration) -> ConnectOptions

Enable TCP keepalive.

pub fn with_keep_alive_while_idle(self, enabled: bool) -> ConnectOptions

Whether send keep alive pings even there are no active requests. If disabled, keep-alive pings are only sent while there are opened request/response streams. If enabled, pings are also sent when no streams are active. NOTE: Some implementations of gRPC server may send GOAWAY if there are too many pings. This would be useful if you meet some error like too many pings.

pub fn with_require_leader(self, require_leader: bool) -> ConnectOptions

Whether to enforce that a leader be present in the etcd cluster.

pub const fn new() -> ConnectOptions

Creates a ConnectOptions.