IP resolution utilities for getting local IP addresses with fallback support
Functions
- get_
http_ rpc_ host - Get the local IP address for HTTP RPC host binding using the default resolver
- get_
http_ rpc_ host_ from_ env - Get the HTTP RPC host from environment variable or resolve local IP as fallback
- get_
http_ rpc_ host_ with_ resolver - Get the local IP address for HTTP RPC host binding, using IpResolver with fallback to 127.0.0.1
- get_
tcp_ rpc_ host_ from_ env - Get the TCP RPC host from environment variable or resolve local IP as fallback